StdLog
=============

.. currentmodule:: biskit

.. autoclass:: StdLog
   :members:
   :show-inheritance:
   :special-members: __init__

   

   
   .. rubric:: Methods Overview

   .. autosummary::
      :nosignatures:
   
   
      ~StdLog.__init__
      ~StdLog.add
      ~StdLog.add_nobreak
      ~StdLog.f
      ~StdLog.write
      ~StdLog.writeln
   
   

   
   
   

   
   
   .. raw:: html
      
      <hr>
      <h2>StdLog Method & Attribute Details</h2>

   
   